@@ -1,3 +1,4 @@
+use crate::error::Error;
 use bitflags::bitflags;
 use pdb::{
     ArgumentList, ArrayType, ClassKind, ClassType, DebugInformation, FallibleIterator,
@@ -13,36 +14,6 @@ use std::collections::HashMap;
 use std::fmt::Write;
 use std::ops::Bound;
 
-#[derive(thiserror::Error, Debug)]
-pub enum Error {
-    #[error("Formatting error: {0}")]
-    FormatError(#[source] std::fmt::Error),
-
-    #[error("PDB error: {0}")]
-    PdbError(#[source] pdb::Error),
-
-    #[error("Unexpected type for argument list")]
-    ArgumentTypeNotArgumentList,
-
-    #[error("Id of type Function doesn't have type of Procedure")]
-    FunctionIdIsNotProcedureType,
-
-    #[error("Id of type MemberFunction doesn't have type of MemberFunction")]
-    MemberFunctionIdIsNotMemberFunctionType,
-}
-
-impl From<pdb::Error> for Error {
-    fn from(err: pdb::Error) -> Self {
-        Self::PdbError(err)
-    }
-}
-
-impl From<std::fmt::Error> for Error {
-    fn from(err: std::fmt::Error) -> Self {
-        Self::FormatError(err)
-    }
-}
-
 type Result<V> = std::result::Result<V, Error>;
 
 bitflags! {
